@@ -207,8 +207,7 @@ class Action(ActionBase):
 
         print_to_stdout(
             content=collections_info,
-            content_format=ContentFormat.YAML,
-            share_directory=self._args.internals.share_directory,
+            content_format=getattr(ContentFormat, self._args.format.upper()),
             use_color=self._args.display_color,
         )
         return RunStdoutReturn(message="", return_code=0)
@@ -218,7 +217,7 @@ class Action(ActionBase):
         msgs = ["humph. no collections were found in the following paths:"]
         paths = []
         for path in self._collection_scanned_paths:
-            if path.startswith(self._args.internals.share_directory):
+            if path.startswith(self._args.internals.cache_path):
                 continue
             if self._args.execution_environment:
                 if path.startswith(self._adjacent_collection_dir):
@@ -364,6 +363,7 @@ class Action(ActionBase):
     def _run_runner(self) -> None:
         # pylint: disable=too-many-branches
         # pylint: disable=too-many-statements
+        # pylint: disable=too-many-locals
         """Use the runner subsystem to catalog collections."""
         if isinstance(self._args.set_environment_variable, dict):
             set_environment_variable = deepcopy(self._args.set_environment_variable)
@@ -418,10 +418,10 @@ class Action(ActionBase):
         kwargs["host_cwd"] = playbook_dir
 
         self._adjacent_collection_dir = os.path.join(playbook_dir, "collections")
-        share_directory = self._args.internals.share_directory
+        cache_path = self._args.internals.cache_path
 
         pass_through_arg = [
-            f"{share_directory}/utils/catalog_collections.py",
+            f"{cache_path}/catalog_collections.py",
             "-a",
             self._adjacent_collection_dir,
             "-c",
@@ -440,8 +440,8 @@ class Action(ActionBase):
             )
 
             container_volume_mounts = [
-                # share utils directory which has introspection script
-                f"{share_directory}/utils:{share_directory}/utils",
+                # cache directory which has introspection script
+                f"{cache_path}:{cache_path}",
                 # KVS library used by both Navigator and the introspection script
                 f"{utils_lib}:/opt/ansible_navigator_utils",
             ]
@@ -450,13 +450,23 @@ class Action(ActionBase):
                     f"{self._adjacent_collection_dir}:{self._adjacent_collection_dir}:z",
                 )
 
-            # The playbook directory will be mounted as host_cwd, so don't duplicate
-            if not path_is_relative_to(
-                child=Path(self._collection_cache_path),
-                parent=(Path(playbook_dir)),
+            mount_doc_cache = True
+            # Determine if the doc_cache is relative to the cache directory
+            if path_is_relative_to(
+                child=Path(self._args.collection_doc_cache_path), parent=(cache_path)
             ):
+                mount_doc_cache = False
+
+            # The playbook directory will be mounted as host_cwd, so don't duplicate
+            if path_is_relative_to(
+                child=Path(self._args.collection_doc_cache_path), parent=(Path(playbook_dir))
+            ):
+                mount_doc_cache = False
+
+            if mount_doc_cache:
                 container_volume_mounts.append(
-                    f"{self._collection_cache_path}:{self._collection_cache_path}:z",
+                    f"{self._args.collection_doc_cache_path}:"
+                    f"{self._args.collection_doc_cache_path}:z",
                 )
 
             for volume_mount in container_volume_mounts:
@@ -486,12 +496,14 @@ class Action(ActionBase):
             self._parse(output)
 
     def _parse(self, output) -> None:
-        # pylint: disable=too-many-branches
         """Load and process the ``json`` output from the collection cataloging process.
 
         :param output: The output from the collection cataloging process
         :returns: Nothing
         """
+        # pylint: disable=too-many-branches
+        # pylint: disable=too-many-locals
+        # pylint: disable=too-many-statements
         try:
             if not output.startswith("{"):
                 _warnings, json_str = output.split("{", 1)
@@ -513,12 +525,36 @@ class Action(ActionBase):
             list(parsed["collections"].values()),
             key=lambda i: i["known_as"],
         )
+        volume_mounts = self.app.args.execution_environment_volume_mounts
+        if isinstance(volume_mounts, list):
+            tmp_list = []
+            for mount in volume_mounts:
+                source_str, destination_str = mount.split(":")[0:2]
+                if not Path(source_str).is_dir():
+                    continue
+                dest_path = Path(destination_str)
+                # /x/ansible_collections/co:/x/ansible_collections/co
+                if dest_path.parent.name == "ansible_collections":
+                    continue
+                # /x/ansible_collections/co/ns:/x/ansible_collections/co/ns
+                if dest_path.parent.parent.name == "ansible_collections":
+                    continue
+                # /x:/x
+                if dest_path.name != "ansible_collections":
+                    dest_path /= "ansible_collections"
+                tmp_list.append(str(dest_path))
+            dest_volume_mounts = tuple(tmp_list)
+        else:
+            dest_volume_mounts = tuple()
+
         for collection in self._collections:
             collection["__name"] = collection["known_as"]
             collection["__version"] = collection["collection_info"].get("version", "missing")
             collection["__shadowed"] = bool(collection["hidden_by"])
             if self._args.execution_environment:
-                if collection["path"].startswith(self._adjacent_collection_dir):
+                if collection["path"].startswith(dest_volume_mounts):
+                    collection["__type"] = "bind_mount"
+                elif collection["path"].startswith(self._adjacent_collection_dir):
                     collection["__type"] = "bind_mount"
                 elif collection["path"].startswith(os.path.dirname(self._adjacent_collection_dir)):
                     collection["__type"] = "bind_mount"
@@ -560,7 +596,6 @@ class Action(ActionBase):
         plugins_details: dict = {}
 
         for plugin_checksum, plugin_info in selected_collection["plugin_checksums"].items():
-
             plugin_type = plugin_info.get("type")
             if plugin_type not in plugins_details:
                 plugins_details[plugin_type] = []
