@@ -1,4 +1,6 @@
 """Config subcommand implementation."""
+from __future__ import annotations
+
 import curses
 import os
 import re
@@ -6,16 +8,11 @@ import shlex
 import shutil
 
 from typing import Any
-from typing import Dict
-from typing import List
-from typing import Optional
-from typing import Tuple
-from typing import Union
 
 from ..action_base import ActionBase
 from ..action_defs import RunStdoutReturn
 from ..app_public import AppPublic
-from ..configuration_subsystem import ApplicationConfiguration
+from ..configuration_subsystem.definitions import ApplicationConfiguration
 from ..runner import AnsibleConfig
 from ..runner import Command
 from ..steps import Step
@@ -31,7 +28,7 @@ from . import _actions as actions
 from . import run_action
 
 
-def color_menu(colno: int, colname: str, entry: Dict[str, Any]) -> Tuple[int, int]:
+def color_menu(colno: int, colname: str, entry: dict[str, Any]) -> tuple[int, int]:
     # pylint: disable=unused-argument
     """Provide a color for a collections menu entry in one column.
 
@@ -45,7 +42,7 @@ def color_menu(colno: int, colname: str, entry: Dict[str, Any]) -> Tuple[int, in
     return 2, 0
 
 
-def content_heading(obj: Any, screen_w: int) -> Optional[CursesLines]:
+def content_heading(obj: Any, screen_w: int) -> CursesLines | None:
     """Create a heading for config content.
 
     :param obj: The content going to be shown
@@ -71,7 +68,7 @@ def content_heading(obj: Any, screen_w: int) -> Optional[CursesLines]:
     return CursesLines((CursesLine((line_part,)),))
 
 
-def filter_content_keys(obj: Dict[Any, Any]) -> Dict[Any, Any]:
+def filter_content_keys(obj: dict[Any, Any]) -> dict[Any, Any]:
     """Filter out some keys when showing collection content.
 
     :param obj: The object from which keys should be removed
@@ -93,10 +90,10 @@ class Action(ActionBase):
         """
         super().__init__(args=args, logger_name=__name__, name="config")
 
-        self._config: Optional[List[Any]] = None
-        self._runner: Union[AnsibleConfig, Command]
+        self._config: list[Any] | None = None
+        self._runner: AnsibleConfig | Command
 
-    def run(self, interaction: Interaction, app: AppPublic) -> Optional[Interaction]:
+    def run(self, interaction: Interaction, app: AppPublic) -> Interaction | None:
         """Execute the ``config`` request for mode interactive.
 
         :param interaction: The interaction from the user
@@ -211,7 +208,7 @@ class Action(ActionBase):
             index=self.steps.current.index,
         )
 
-    def _run_runner(self) -> Optional[Tuple]:
+    def _run_runner(self) -> tuple | None:
         # pylint: disable=too-many-branches
         # pylint: disable=too-many-statements
         """Use the runner subsystem to retrieve the configuration.
@@ -264,7 +261,7 @@ class Action(ActionBase):
                 msg = f"Error occurred while fetching ansible config (dump): '{dump_output_err}'"
                 self._logger.error(msg)
 
-            err_msg = "\n".join(set((list_output_err, dump_output_err)))
+            err_msg = "\n".join({list_output_err, dump_output_err})
             if "ERROR!" in err_msg or not list_output or not dump_output:
                 warn_msg = ["Errors were encountered while gathering the configuration:"]
                 if err_msg:
