@@ -148,8 +148,7 @@ class Action(ActionBase):
             filtered.append(filter_content_keys(image))
         print_to_stdout(
             content=filtered,
-            content_format=ContentFormat.YAML,
-            share_directory=self._args.internals.share_directory,
+            content_format=getattr(ContentFormat, self._args.format.upper()),
             use_color=self._args.display_color,
         )
         return RunStdoutReturn(message="", return_code=0)
@@ -184,7 +183,6 @@ class Action(ActionBase):
         print_to_stdout(
             content=details,
             content_format=ContentFormat.YAML,
-            share_directory=self._args.internals.share_directory,
             use_color=self._args.display_color,
         )
         return RunStdoutReturn(message="", return_code=0)
@@ -441,12 +439,30 @@ class Action(ActionBase):
                 image["__name"] += " (primary)"
                 image["__name_tag"] += " (primary)"
 
+            details = image["inspect"]["details"]
+
             try:
-                image["execution_environment"] = (
-                    image["inspect"]["details"]["config"]["working_dir"] == "/runner"
-                )
+                legacy_check = details["config"]["working_dir"] == "/runner"
             except KeyError:
-                image["execution_environment"] = False
+                legacy_check = False
+
+            # podman has a root label
+            try:
+                root_label_check = details["labels"]["ansible-execution-environment"] == "true"
+            except (KeyError, TypeError):
+                root_label_check = False
+
+            # docker has only a config.label
+            try:
+                config_label_check = (
+                    details["config"]["labels"]["ansible-execution-environment"] == "true"
+                )
+            except (KeyError, TypeError):
+                config_label_check = False
+
+            image["execution_environment"] = any(
+                (legacy_check, root_label_check, config_label_check)
+            )
         self._images.value = sorted(images, key=lambda i: i["name"])
 
     def _introspect_image(self) -> bool:
@@ -533,12 +549,12 @@ class Action(ActionBase):
         :param image_name: The full image name
         :returns: Output, errors and the return code
         """
-        share_directory = self._args.internals.share_directory
-        container_volume_mounts = [f"{share_directory}/utils:{share_directory}/utils"]
+        cache_path = self._args.internals.cache_path
+        container_volume_mounts = [f"{cache_path}:{cache_path}"]
         python_exec_path = "python3"
 
         kwargs = {
-            "cmdline": [f"{share_directory}/utils/image_introspect.py"],
+            "cmdline": [f"{cache_path}/image_introspect.py"],
             "container_engine": self._args.container_engine,
             "container_volume_mounts": container_volume_mounts,
             "execution_environment_image": image_name,
