@@ -17,7 +17,6 @@ from pathlib import Path
 from queue import Queue
 from typing import Any
 from typing import Callable
-from typing import Dict
 
 from ..action_base import ActionBase
 from ..action_defs import RunStdoutReturn
@@ -38,6 +37,7 @@ from ..ui_framework import form_to_dict
 from ..ui_framework import nonblocking_notification
 from ..ui_framework import warning_notification
 from ..utils.functions import abs_user_path
+from ..utils.functions import check_playbook_type
 from ..utils.functions import human_time
 from ..utils.functions import is_jinja
 from ..utils.functions import now_iso
@@ -192,7 +192,6 @@ TASK_LIST_COLUMNS = [
 
 @actions.register
 class Action(ActionBase):
-
     # pylint: disable=too-many-instance-attributes
     """Run command implementation."""
 
@@ -228,6 +227,7 @@ class Action(ActionBase):
         )
         self._task_list_columns: list[str] = TASK_LIST_COLUMNS
         self._content_key_filter: Callable = filter_content_keys
+        self._playbook_type: str = check_playbook_type(self._args.playbook)
         self._task_cache: dict[str, str] = {}
         """Task name storage from playbook_on_start using the task uuid as the key"""
 
@@ -250,7 +250,7 @@ class Action(ActionBase):
         return self._args.mode
 
     def run_stdout(self) -> RunStdoutReturn:
-        """Execute the ``inventory`` request for mode stdout.
+        """Execute the ``run`` request for mode stdout.
 
         :returns: The return code from the runner invocation, along with a message to review the
             logs if not 0
@@ -363,27 +363,27 @@ class Action(ActionBase):
         if not args_updated:
             return False
 
-        if isinstance(self._args.playbook, str):
-            playbook_valid = os.path.exists(self._args.playbook)
-        else:
-            playbook_valid = False
+        if self._playbook_type == "file":
+            if isinstance(self._args.playbook, str):
+                playbook_valid = os.path.exists(self._args.playbook)
+            else:
+                playbook_valid = False
 
-        if not playbook_valid:
+            if not playbook_valid:
+                populated_form = self._prompt_for_playbook()
+                if populated_form["cancelled"]:
+                    return False
 
-            populated_form = self._prompt_for_playbook()
-            if populated_form["cancelled"]:
-                return False
+                new_cmd = ["run"]
+                new_cmd.append(populated_form["fields"]["playbook"]["value"])
 
-            new_cmd = ["run"]
-            new_cmd.append(populated_form["fields"]["playbook"]["value"])
+                if populated_form["fields"]["cmdline"]["value"]:
+                    new_cmd.extend(shlex.split(populated_form["fields"]["cmdline"]["value"]))
 
-            if populated_form["fields"]["cmdline"]["value"]:
-                new_cmd.extend(shlex.split(populated_form["fields"]["cmdline"]["value"]))
-
-            # Parse as if provided from the cmdline
-            args_updated = self._update_args(new_cmd)
-            if not args_updated:
-                return False
+                # Parse as if provided from the cmdline
+                args_updated = self._update_args(new_cmd)
+                if not args_updated:
+                    return False
 
         self._run_runner()
         self._logger.info("Run initialized and playbook started.")
@@ -465,7 +465,7 @@ class Action(ActionBase):
         if not isinstance(artifact_file, str):
             artifact_file = ""
 
-        FType = Dict[str, Any]
+        FType = dict[str, Any]
         form_dict: FType = {
             "title": "Artifact file not found, please confirm the following",
             "fields": [],
@@ -484,7 +484,7 @@ class Action(ActionBase):
         return populated_form
 
     def _prompt_for_playbook(self) -> dict[Any, Any]:
-        """Prepopulate a form to confirm the playbook details.
+        """Pre-populate a form to confirm the playbook details.
 
         :returns: Dict with playbook and inventory detail entries
         """
@@ -500,7 +500,7 @@ class Action(ActionBase):
         else:
             cmdline = ""
 
-        FType = Dict[str, Any]
+        FType = dict[str, Any]
         form_dict: FType = {
             "title": "Playbook not found, please confirm the following",
             "fields": [],
@@ -537,7 +537,6 @@ class Action(ActionBase):
                 self.steps.current.show_func()
 
             if self.steps.current.type == "menu":
-
                 new_scroll = len(self.steps.current.value)
                 if self._auto_scroll:
                     self._interaction.ui.scroll(new_scroll)
@@ -549,10 +548,10 @@ class Action(ActionBase):
                 )
 
                 if self._interaction.ui.scroll() < new_scroll and self._auto_scroll:
-                    self._logger.debug("autoscroll disabled")
+                    self._logger.debug("auto_scroll disabled")
                     self._auto_scroll = False
                 elif self._interaction.ui.scroll() >= new_scroll and not self._auto_scroll:
-                    self._logger.debug("autoscroll enabled")
+                    self._logger.debug("auto_scroll enabled")
                     self._auto_scroll = True
 
             elif self.steps.current.type == "content":
@@ -628,7 +627,12 @@ class Action(ActionBase):
             pass_through_arg.extend(self._args.cmdline)
         kwargs.update({"cmdline": pass_through_arg})
 
-        self.runner = CommandAsync(executable_cmd=executable_cmd, queue=self._queue, **kwargs)
+        self.runner = CommandAsync(
+            executable_cmd=executable_cmd,
+            queue=self._queue,
+            write_job_events=self._args.ansible_runner_write_job_events,
+            **kwargs,
+        )
         self.runner.run()
         self._runner_finished = False
         self._logger.debug("runner requested to start")
@@ -887,17 +891,15 @@ class Action(ActionBase):
         :param filename: The file to write to
         :type filename: str
         """
-        if (
-            filename
-            or self._args.playbook_artifact_enable is True
-            and self._args.help_playbook is not True
-        ):
+        if filename or self._args.playbook_artifact_enable is True:
             status, status_color = self._get_status()
-
+            playbook = self._args.playbook
+            if self._playbook_type == "fqcn" and len(self._plays.value) > 0:
+                playbook = [k["playbook"] for k in self._plays.value][0]
             filename = filename or self._args.playbook_artifact_save_as
             filename = filename.format(
-                playbook_dir=os.path.dirname(self._args.playbook),
-                playbook_name=os.path.splitext(os.path.basename(self._args.playbook))[0],
+                playbook_dir=os.path.dirname(playbook),
+                playbook_name=os.path.splitext(os.path.basename(playbook))[0],
                 playbook_status=status,
                 time_stamp=now_iso(self._args.time_zone),
             )
