@@ -2,6 +2,7 @@
 """Navigator entry point."""
 from __future__ import annotations
 
+import filecmp
 import logging
 import os
 import signal
@@ -9,9 +10,10 @@ import sys
 
 from copy import deepcopy
 from curses import wrapper
+from importlib.metadata import version
+from importlib.util import find_spec
 from pathlib import Path
-
-from pkg_resources import working_set
+from shutil import copyfile
 
 from .action_defs import ActionReturn
 from .action_defs import RunInteractiveReturn
@@ -26,10 +28,13 @@ from .image_manager import ImagePuller
 from .initialization import error_and_exit_early
 from .initialization import parse_and_update
 from .logger import setup_logger
+from .utils.compatibility import importlib_metadata
 from .utils.definitions import ExitMessage
 from .utils.definitions import ExitPrefix
 from .utils.definitions import LogMessage
 from .utils.functions import clear_screen
+from .utils.functions import generate_cache_path
+from .utils.packaged_data import path_to_file
 
 
 __version__: Constants | str
@@ -45,14 +50,46 @@ PKG_NAME = "ansible_navigator"
 logger = logging.getLogger(PKG_NAME)
 
 
+def cache_scripts() -> None:
+    """Cache the scripts used to introspect the container image."""
+    scripts = ("catalog_collections.py", "image_introspect.py")
+    for script in scripts:
+        src = path_to_file(filename=script)
+        cache_path = generate_cache_path(app_name=APP_NAME)
+        cache_path.mkdir(parents=True, exist_ok=True)
+        dst = cache_path / script
+        message = f"No update required for {src} to {dst}"
+        try:
+            if not filecmp.cmp(src, dst):
+                copyfile(src, dst)
+                message = f"Updated {src} to {dst} (outdated)"
+        except FileNotFoundError:
+            copyfile(src, dst)
+            message = f"Copied {src} to {dst} (missing)"
+        logger.log(level=logging.DEBUG, msg=message)
+
+
 def log_dependencies() -> list[LogMessage]:
     """Retrieve installed packages and log as debug.
 
     :returns: All packages, version and location
     """
-    # pylint: disable=not-an-iterable
-    installed_packages_list = sorted(f"{i.key}=={i.version} {i.location}" for i in working_set)
-    messages = [LogMessage(level=logging.DEBUG, message=pkg) for pkg in installed_packages_list]
+    pkgs = []
+    found = []
+    for _python_name, pkg_names in importlib_metadata.packages_distributions().items():
+        for pkg_name in pkg_names:
+            if pkg_name not in found:
+                found.append(pkg_name)
+                spec = find_spec(pkg_name)
+                if spec:
+                    _location = spec.origin
+                else:
+                    _location = ""
+                _version = version(pkg_name)
+                pkgs.append(f"{pkg_name}=={_version} {_location}")
+
+    pkgs.sort()
+    messages = [LogMessage(level=logging.DEBUG, message=pkg) for pkg in pkgs]
     return messages
 
 
@@ -73,8 +110,6 @@ def pull_image(args):
     if image_puller.assessment.pull_required:
         image_puller.prologue_stdout()
         image_puller.pull_stdout()
-    if image_puller.assessment.exit_messages:
-        error_and_exit_early(image_puller.assessment.exit_messages)
 
 
 def run(args: ApplicationConfiguration) -> ActionReturn:
@@ -155,12 +190,15 @@ def main():
 
     if args.execution_environment:
         pull_image(args)
+        cache_scripts()
 
     run_return = run(args)
     run_message = f"{run_return.message}\n"
     if run_return.return_code != 0 and run_return.message:
         sys.stderr.write(run_message)
         sys.exit(run_return.return_code)
+    elif run_return.return_code != 0:
+        sys.exit(run_return.return_code)
     elif run_return.message:
         sys.stdout.write(run_message)
 
