@@ -4,6 +4,7 @@ from __future__ import annotations
 import copy
 import re
 
+from collections.abc import Iterable
 from dataclasses import InitVar
 from dataclasses import dataclass
 from dataclasses import field
@@ -11,13 +12,11 @@ from enum import Enum
 from pathlib import Path
 from typing import TYPE_CHECKING
 from typing import Any
-from typing import Dict
-from typing import Iterable
-from typing import List
 from typing import NewType
 from typing import TypeVar
 from typing import Union
 
+from ..utils.functions import abs_user_path
 from ..utils.functions import oxfordcomma
 
 
@@ -53,7 +52,8 @@ class Constants(Enum):
         " that it will only be used if the subcommand is the same"
     )
     SEARCH_PATH = "Search path"
-    SENTINEL = "Indicates a nonvalue"
+    SENTINEL = "Indicates a non value"
+    TEST = "Indicates a value set from a test"
     USER_CFG = "Settings file"
     USER_CLI = "Command line"
 
@@ -274,6 +274,13 @@ class ApplicationConfiguration:
         return self.application_name.replace("_", "-")
 
     def _get_by_name(self, name, kind):
+        """Retrieve a settings entry by name.
+
+        :param name: The name of the entry
+        :param kind: The kind of entry to retrieve
+        :returns: The settings entry
+        :raises KeyError: If the entry is not found
+        """
         try:
             return next(entry for entry in super().__getattribute__(kind) if entry.name == name)
         except StopIteration as exc:
@@ -319,6 +326,15 @@ class VolumeMountOption(Enum):
     keep in mind that we support both runtimes.
     """
 
+    # Overlay
+    OVERLAY = "O"
+
+    # Read Only
+    ro = "ro"  # pylint: disable=invalid-name
+
+    # Read Write
+    rw = "rw"  # pylint: disable=invalid-name
+
     # Relabel as private
     Z = "Z"
 
@@ -356,47 +372,58 @@ class VolumeMount:
         :raises VolumeMountError: When a viable VolumeMount cannot be created
         :param options_string: Option entries in as type string
         """
-        # pylint: disable=too-many-branches
         errors = []
-        # Validate the source
-        if isinstance(self.fs_source, str):
-            if self.fs_source == "":
-                errors.append("Source not provided.")
-            elif not Path(self.fs_source).exists():
-                errors.append(f"Source: '{self.fs_source}' does not exist.")
-        else:
-            errors.append(f"Source: '{self.fs_source}' is not a string.")
 
-        # Validate the destination
-        if isinstance(self.fs_destination, str):
-            if self.fs_destination == "":
-                errors.append("Destination not provided.")
-        else:
+        # Ensure each is a string
+        if not isinstance(self.fs_source, str):
+            errors.append(f"Source: '{self.fs_source}' is not a string.")
+        if not isinstance(self.fs_destination, str):
             errors.append(f"Destination: '{self.fs_destination}' is not a string.")
+        if not isinstance(options_string, str):
+            errors.append(f"Options: '{options_string}' is not a string.")
+
+        # Ensure source and dest are not empty
+        if self.fs_source == "":
+            errors.append("Source not provided.")
+        if self.fs_destination == "":
+            errors.append("Destination not provided.")
+
+        # Exit early for errors
+        if errors:
+            raise VolumeMountError(" ".join(errors))
+
+        # Resolve the source and destination
+        # frozen, cannot use simple assignment to initialize fields, and must use:
+        object.__setattr__(self, "fs_source", abs_user_path(self.fs_source))
+        object.__setattr__(self, "fs_destination", abs_user_path(self.fs_destination))
+
+        # Source must exist
+        if not Path(self.fs_source).exists():
+            error_msg = f"Source: '{self.fs_source}' does not exist."
+            raise VolumeMountError(error_msg)
 
         # Validate and populate _options
-        if isinstance(options_string, str):
-            if not options_string == "":
-                options = []
-                option_values = [o.value for o in VolumeMountOption]
-                for option in options_string.split(","):
-                    if option not in option_values:
-                        errors.append(
-                            f"Unrecognized option: '{option}',"
-                            f" available options include"
-                            f" {oxfordcomma(option_values, condition='and/or')}.",
-                        )
-                    else:
-                        options.append(VolumeMountOption(option))
-                unique = sorted(set(options), key=options.index)
-                # frozen, cannot use simple assignment to initialize fields, and must use:
-                object.__setattr__(self, "options", tuple(unique))
-        else:
-            errors.append(f"Options: '{options_string}' is not a string.")
+        if options_string == "":
+            return
+
+        options = []
+        option_values = [o.value for o in VolumeMountOption]
+        for option in options_string.split(","):
+            if option not in option_values:
+                errors.append(
+                    f"Unrecognized option: '{option}',"
+                    f" available options include"
+                    f" {oxfordcomma(option_values, condition='and/or')}.",
+                )
+            else:
+                options.append(VolumeMountOption(option))
 
         if errors:
             raise VolumeMountError(" ".join(errors))
 
+        unique = sorted(set(options), key=options.index)
+        object.__setattr__(self, "options", tuple(unique))
+
     def to_string(self) -> str:
         """Render the volume mount in a way that (docker|podman) understands.
 
@@ -429,13 +456,23 @@ class ModeChangeRequest:
     """The desired mode"""
 
 
+@dataclass
+class PaeChangeRequest:
+    """Data structure to hold playbook artifact change request by a settings entry."""
+
+    entry: str
+    """The entry making the request"""
+    playbook_artifact_enable: bool
+    """The desired value for playbook_artifact_enable"""
+
+
 # and some common ones
 
 # A type used for the settings as a dictionary
-SettingsFileType = NewType("SettingsFileType", Dict[str, Union[bool, Dict, int, str, List]])
+SettingsFileType = NewType("SettingsFileType", dict[str, Union[bool, dict, int, str, list]])
 
 # A type used to describe a schema file for the settings
 SettingsSchemaType = NewType(
     "SettingsSchemaType",
-    Dict[str, Dict[str, Union[bool, Dict, int, str, List]]],
+    dict[str, dict[str, Union[bool, dict, int, str, list]]],
 )
