@@ -6,13 +6,15 @@ import os
 
 from dataclasses import dataclass
 from dataclasses import field
+from pathlib import Path
 
 from ..utils.definitions import ExitMessage
 from ..utils.definitions import LogMessage
 from ..utils.functions import abs_user_path
-from ..utils.functions import get_share_directory
+from ..utils.functions import generate_cache_path
 from ..utils.functions import oxfordcomma
 from ..utils.key_value_store import KeyValueStore
+from ..utils.packaged_data import ImageEntry
 from .definitions import ApplicationConfiguration
 from .definitions import CliParameters
 from .definitions import Constants as C
@@ -64,28 +66,17 @@ def generate_editor_command() -> str:
     return command
 
 
-def generate_cache_path():
+def _generate_doc_cache_path() -> str:
     """Generate a path for the collection cache.
 
     :returns: Collection cache path
     """
     file_name = "collection_doc_cache.db"
-    cache_home = os.environ.get("XDG_CACHE_HOME", f"{os.path.expanduser('~')}/.cache")
-    cache_path = os.path.join(cache_home, APP_NAME.replace("_", "-"), file_name)
+    cache_dir = generate_cache_path(APP_NAME.replace("_", "-"))
+    cache_path = cache_dir / file_name
     message = f"Default collection_doc_cache_path set to: {cache_path}"
     initialization_messages.append(LogMessage(level=logging.DEBUG, message=message))
-    return cache_path
-
-
-def generate_share_directory():
-    """Generate a share director.
-
-    :returns: Share directory path
-    """
-    messages, exit_messages, share_directory = get_share_directory(APP_NAME)
-    initialization_messages.extend(messages)
-    initialization_exit_messages.extend(exit_messages)
-    return share_directory
+    return str(cache_path)
 
 
 @dataclass
@@ -94,6 +85,7 @@ class Internals:
 
     ansible_configuration: AnsibleConfiguration = field(default_factory=AnsibleConfiguration)
     action_packages: tuple[str] = ("ansible_navigator.actions",)
+    cache_path: Path = generate_cache_path(APP_NAME.replace("_", "-"))
     collection_doc_cache: C | KeyValueStore = C.NOT_SET
     initializing: bool = False
     """This is an initial run (app starting for the first time)."""
@@ -101,7 +93,6 @@ class Internals:
     initialization_messages = initialization_messages
     settings_file_path: str | None = None
     settings_source: C = C.NOT_SET
-    share_directory: str = generate_share_directory()
 
 
 navigator_subcommands = [
@@ -244,6 +235,15 @@ NavigatorConfiguration = ApplicationConfiguration(
             value=SettingsEntryValue(),
             version_added="v1.0",
         ),
+        SettingsEntry(
+            name="ansible_runner_write_job_events",
+            choices=[True, False],
+            cli_parameters=CliParameters(short="--rwje", action="store_true"),
+            settings_file_path_override="ansible-runner.job-events",
+            short_description="Write ansible-runner job_events in the artifact directory",
+            value=SettingsEntryValue(default=False),
+            version_added="v2.3",
+        ),
         SettingsEntry(
             name="app",
             apply_to_subsequent_cli=C.NONE,
@@ -266,7 +266,7 @@ NavigatorConfiguration = ApplicationConfiguration(
             cli_parameters=CliParameters(short="--cdcp"),
             short_description="The path to collection doc cache",
             value=SettingsEntryValue(
-                default=generate_cache_path(),
+                default=_generate_doc_cache_path(),
                 schema_default="~/.cache/ansible-navigator/collection_doc_cache.db",
             ),
             version_added="v1.0",
@@ -330,6 +330,16 @@ NavigatorConfiguration = ApplicationConfiguration(
             value=SettingsEntryValue(default=True),
             version_added="v1.0",
         ),
+        SettingsEntry(
+            name="enable_prompts",
+            choices=[True, False],
+            cli_parameters=CliParameters(short="--ep", action="store_true"),
+            short_description="Enable prompts for password and in playbooks. This will set"
+            " mode to stdout and disable playbook artifact creation",
+            subcommands=["run"],
+            value=SettingsEntryValue(default=False),
+            version_added="v2.3",
+        ),
         SettingsEntry(
             name="exec_command",
             cli_parameters=CliParameters(positional=True),
@@ -364,7 +374,7 @@ NavigatorConfiguration = ApplicationConfiguration(
             settings_file_path_override="execution-environment.image",
             short_description="Specify the name of the execution environment image",
             value=SettingsEntryValue(
-                default="quay.io/ansible/creator-ee:v0.9.1",
+                default=ImageEntry.DEFAULT_EE.get(app_name=APP_NAME),
                 schema_default=C.NONE,
             ),
             version_added="v1.0",
@@ -382,6 +392,15 @@ NavigatorConfiguration = ApplicationConfiguration(
             value=SettingsEntryValue(),
             version_added="v1.0",
         ),
+        SettingsEntry(
+            name="format",
+            choices=["json", "yaml"],
+            cli_parameters=CliParameters(short="--fmt"),
+            short_description="Specify the format for stdout output.",
+            subcommands=["collections", "images"],
+            value=SettingsEntryValue(default="yaml"),
+            version_added="v2.3",
+        ),
         SettingsEntry(
             name="help_builder",
             choices=[True, False],
@@ -573,6 +592,7 @@ NavigatorConfiguration = ApplicationConfiguration(
             name="playbook_artifact_enable",
             choices=[True, False],
             cli_parameters=CliParameters(short="--pae"),
+            delay_post_process=True,
             settings_file_path_override="playbook-artifact.enable",
             short_description="Enable or disable the creation of artifacts for"
             " completed playbooks. Note: not compatible with '--mode stdout' when playbooks"
@@ -596,7 +616,7 @@ NavigatorConfiguration = ApplicationConfiguration(
             settings_file_path_override="playbook-artifact.save-as",
             short_description=(
                 "Specify the name for artifacts created from completed playbooks."
-                "The following placeholders are available: {playbook_dir}, {playbook_name},"
+                " The following placeholders are available: {playbook_dir}, {playbook_name},"
                 " {playbook_status}, and {time_stamp}"
             ),
             subcommands=["run"],
