@@ -8,21 +8,20 @@ import os
 import shlex
 import shutil
 import sys
+import zoneinfo
 
 from functools import partialmethod
 from itertools import chain
 from itertools import repeat
 from pathlib import Path
 from string import Formatter
-from typing import List
-from typing import Tuple
 
-from ..utils.compatibility import zoneinfo
 from ..utils.definitions import ExitMessage
 from ..utils.definitions import ExitPrefix
 from ..utils.definitions import LogMessage
 from ..utils.functions import abs_user_path
 from ..utils.functions import check_for_ansible
+from ..utils.functions import check_playbook_type
 from ..utils.functions import flatten_list
 from ..utils.functions import oxfordcomma
 from ..utils.functions import str2bool
@@ -32,12 +31,19 @@ from .definitions import CliParameters
 from .definitions import Constants as C
 from .definitions import Mode
 from .definitions import ModeChangeRequest
+from .definitions import PaeChangeRequest
 from .definitions import SettingsEntry
 from .definitions import VolumeMount
 from .definitions import VolumeMountError
 
 
 def _post_processor(func):
+    """Decorate a post processing function.
+
+    :param func: The function to wrap
+    :returns: The wrapped function
+    """
+
     def wrapper(*args, **kwargs):
         name = kwargs["entry"].name
         before = str(kwargs["entry"].value.current)
@@ -58,7 +64,7 @@ def _post_processor(func):
     return wrapper
 
 
-PostProcessorReturn = Tuple[List[LogMessage], List[ExitMessage]]
+PostProcessorReturn = tuple[list[LogMessage], list[ExitMessage]]
 
 
 class NavigatorPostProcessor:
@@ -72,6 +78,7 @@ class NavigatorPostProcessor:
         #: :meth:`.execution_environment_volume_mounts` post-processor.
         self.extra_volume_mounts: list[VolumeMount] = []
         self._requested_mode: list[ModeChangeRequest] = []
+        self._requested_pae: list[PaeChangeRequest] = []
 
     @staticmethod
     def _true_or_false(
@@ -79,6 +86,12 @@ class NavigatorPostProcessor:
         config: ApplicationConfiguration,
     ) -> PostProcessorReturn:
         # pylint: disable=unused-argument
+        """Post process a boolean value.
+
+        :param entry: The current settings entry
+        :param config: The full application configuration
+        :returns: An instance of the standard post process return object
+        """
         messages: list[LogMessage] = []
         exit_messages: list[ExitMessage] = []
         try:
@@ -131,6 +144,9 @@ class NavigatorPostProcessor:
                 exit_messages.append(ExitMessage(message=exit_msg))
         return messages, exit_messages
 
+    # Post process ansible_runner_write_job_events.
+    ansible_runner_write_job_events = _true_or_false
+
     @staticmethod
     @_post_processor
     def ansible_runner_timeout(
@@ -464,6 +480,37 @@ class NavigatorPostProcessor:
             entry.value.current = flatten_list(entry.value.current)
         return messages, exit_messages
 
+    @_post_processor
+    def _disable_pae_and_enforce_stdout(
+        self,
+        entry: SettingsEntry,
+        config: ApplicationConfiguration,
+    ) -> PostProcessorReturn:
+        """Disable playbook artifact creation and force mode stdout for a settings parameter.
+
+        :param entry: The current settings entry
+        :param config: The full application configuration
+        :returns: An instance of the standard post process return object
+        """
+        messages, exit_messages = self._true_or_false(entry, config)
+        if entry.value.current is True:
+            mode = Mode.STDOUT
+            playbook_artifact_enable = False
+            self._requested_mode.append(ModeChangeRequest(entry=entry.name, mode=mode))
+            self._requested_pae.append(
+                PaeChangeRequest(
+                    entry=entry.name, playbook_artifact_enable=playbook_artifact_enable
+                )
+            )
+            message = (
+                f"`{entry.name} requesting mode {mode.value} and pae as {playbook_artifact_enable}"
+            )
+            messages.append(LogMessage(level=logging.DEBUG, message=message))
+        return messages, exit_messages
+
+    # Post process for enable_prompts
+    enable_prompts = _disable_pae_and_enforce_stdout
+
     # Post process for exec_shell
     exec_shell = _true_or_false
 
@@ -494,7 +541,9 @@ class NavigatorPostProcessor:
     help_config = partialmethod(_forced_stdout, subcommand="config")
     help_doc = partialmethod(_forced_stdout, subcommand="doc")
     help_inventory = partialmethod(_forced_stdout, subcommand="inventory")
-    help_playbook = partialmethod(_forced_stdout, subcommand="run")
+
+    # Post process for help_playbook
+    help_playbook = _disable_pae_and_enforce_stdout
 
     @_post_processor
     def images_details(
@@ -868,12 +917,49 @@ class NavigatorPostProcessor:
                 exit_msg = "Try again with 'run <playbook name>'"
                 exit_messages.append(ExitMessage(message=exit_msg, prefix=ExitPrefix.HINT))
                 return messages, exit_messages
-        if isinstance(entry.value.current, str):
-            entry.value.current = abs_user_path(entry.value.current)
+        if check_playbook_type(entry.value.current) == "file":
+            if isinstance(entry.value.current, str):
+                entry.value.current = abs_user_path(entry.value.current)
         return messages, exit_messages
 
-    # Post processing of playbook_artifact_enable
-    playbook_artifact_enable = _true_or_false
+    @_post_processor
+    def playbook_artifact_enable(
+        self,
+        entry: SettingsEntry,
+        config: ApplicationConfiguration,
+    ) -> PostProcessorReturn:
+        """Post process playbook_artifact_enable.
+
+        :param entry: The current settings entry
+        :param config: The full application configuration
+        :raises ValueError: When more than 1 pae changes requests are present, shouldn't happen
+        :returns: An instance of the standard post process return object
+        """
+        # pylint: disable=unused-argument
+        messages: list[LogMessage] = []
+        exit_messages: list[ExitMessage] = []
+
+        # Check if any other entry has requested a pae change different than current
+        pae_set = {request.playbook_artifact_enable for request in self._requested_pae}
+        if len(pae_set) == 1:
+            requested = self._requested_pae[0]
+            auto_pae = requested.playbook_artifact_enable
+            if auto_pae != entry.value.current:
+                pae_change_msgs = (
+                    f"Parameter '{requested.entry}' required pae '{auto_pae!s}'.",
+                    f"Pae will be set to '{auto_pae}'",
+                )
+                messages.extend(
+                    LogMessage(level=logging.INFO, message=msg) for msg in pae_change_msgs
+                )
+                entry.value.current = auto_pae
+        elif len(pae_set) > 1:
+            raise ValueError(f"Conflicting pae requests: {self._requested_pae}")
+        try:
+            entry.value.current = str2bool(entry.value.current)
+        except ValueError:
+            pass
+        return messages, exit_messages
 
     @staticmethod
     @_post_processor
