@@ -2,22 +2,19 @@
 from __future__ import annotations
 
 import datetime
-import json
 import sys
 import traceback
 
+from collections.abc import Iterator
 from dataclasses import asdict
 from dataclasses import dataclass
+from importlib.util import find_spec
 from pathlib import Path
 from sys import stdout
+from typing import Any
 from typing import Callable
-from typing import Dict
-from typing import Iterator
-from typing import List
 from typing import Union
 
-from pkg_resources import working_set
-
 from .command_runner import Command
 from .command_runner import CommandRunner
 from .configuration_subsystem import Constants
@@ -27,15 +24,17 @@ from .configuration_subsystem.definitions import ApplicationConfiguration
 from .image_manager import introspect
 from .image_manager import introspector
 from .utils import ansi
+from .utils.compatibility import importlib_metadata
 from .utils.definitions import ExitMessage
 from .utils.definitions import LogMessage
 from .utils.functions import now_iso
 from .utils.functions import shlex_join
 from .utils.serialize import Loader
+from .utils.serialize import write_diagnostics_json
 from .utils.serialize import yaml
 
 
-JSONTypes = Union[bool, int, str, Dict, List]
+JSONTypes = Union[bool, int, str, dict, list[Any]]
 
 
 @dataclass
@@ -214,10 +213,14 @@ class DiagnosticsCollector:
             settings=self._settings(),
             settings_file=self._settings_file(),
         )
+
         time = now_iso("local")
-        path = Path(f"diagnostics-{time}.json")
-        path.write_text(json.dumps(asdict(diagnostics), indent=4, sort_keys=True), encoding="utf-8")
-        message = f"\nDiagnostics written to: {path.resolve()}"
+        file_name = f"diagnostics-{time}.json"
+        path = f"{Path.home()}/{file_name}"
+        mode = 0o600
+        write_diagnostics_json(path, mode, asdict(diagnostics))
+        message = f"\nDiagnostics written to: {path}"
+
         if DIAGNOSTIC_FAILURES > 0:
             ansi.warning(color=self.color, message=message)
         else:
@@ -244,10 +247,11 @@ class DiagnosticsCollector:
             "application_name": self._args.application_name,
             "application_version": str(self._args.application_version),
             "action_packages": list(self._args.internals.action_packages),
+            "cache_path": str(self._args.internals.cache_path),
+            "collection_doc_cache": str(self._args.internals.collection_doc_cache),
             "original_command": shlex_join(sys.argv),
             "settings_file_path": str(self._args.internals.settings_file_path),
             "settings_source": str(self._args.internals.settings_source),
-            "share_directory": self._args.internals.share_directory,
         }
 
     @diagnostic_runner
@@ -261,7 +265,7 @@ class DiagnosticsCollector:
             Command(identity="podman", command="podman --version", post_process=lambda c: c),
             Command(identity="docker", command="docker --version", post_process=lambda c: c),
         ]
-        CommandRunner().run_single_proccess(commands)
+        CommandRunner().run_single_process(commands)
         engines: dict[str, JSONTypes] = {}
         for command in commands:
             engines[command.identity] = {
@@ -354,10 +358,17 @@ class DiagnosticsCollector:
 
         :returns: The python packages information
         """
-        return {
-            i.key: {"location": i.location, "name": i.key, "version": i.version}
-            for i in working_set  # pylint: disable=not-an-iterable
-        }
+        pkgs = importlib_metadata.packages_distributions()
+        meta: dict[str, Any] = {}
+        for _python_name, pkg_names in pkgs.items():
+            for pkg_name in pkg_names:
+                if pkg_name not in meta:
+                    meta[pkg_name] = importlib_metadata.metadata(pkg_name).json
+                    spec = find_spec(pkg_name)
+                    if spec:
+                        meta[pkg_name]["location"] = spec.origin
+                    meta[pkg_name]["requires"] = importlib_metadata.distribution(pkg_name).requires
+        return meta
 
     @diagnostic_runner
     @register(Collector(name="settings"))
