@@ -94,7 +94,7 @@ def inspect_all(container_engine: str) -> tuple[list, str]:
     """
     cmd_runner = CommandRunner()
     images_list_class = ImagesList(container_engine=container_engine)
-    result = cmd_runner.run_single_proccess(commands=images_list_class.commands)
+    result = cmd_runner.run_single_process(commands=images_list_class.commands)
     images_list = result[0]
     if images_list.errors:
         return [], images_list.errors
@@ -103,7 +103,7 @@ def inspect_all(container_engine: str) -> tuple[list, str]:
     images = {image["image_id"]: image for image in images_list.details}
     image_ids = [image["image_id"] for image in images.values()]
     images_inspect_class = ImagesInspect(container_engine=container_engine, ids=image_ids)
-    inspects = cmd_runner.run_single_proccess(commands=images_inspect_class.commands)
+    inspects = cmd_runner.run_single_process(commands=images_inspect_class.commands)
     for inspect in inspects:
         images[inspect.identity]["inspect"] = {"details": inspect.details, "errors": inspect.errors}
     return list(images.values()), images_list.stderr
