@@ -11,14 +11,12 @@ import threading
 from queue import Queue
 from types import SimpleNamespace
 from typing import Callable
-from typing import Dict
-from typing import List
 from typing import Union
 
 
 # pylint: disable=broad-except
 
-JSONTypes = Union[bool, int, str, Dict, List]
+JSONTypes = Union[bool, int, str, dict, list]
 
 
 class Command(SimpleNamespace):
