@@ -86,7 +86,6 @@ class Base:
         self.finished: bool = False
         self.status: str | None = None
         self._runner_args: dict = {}
-        self._runner_artifact_dir: str | None = None
         if self._ee:
             self._runner_args.update(
                 {
@@ -105,7 +104,6 @@ class Base:
                 "quiet": True,
                 "cancel_callback": self.runner_cancelled_callback,
                 "finished_callback": self.runner_finished_callback,
-                "artifacts_handler": self.runner_artifacts_handler,
                 "timeout": self._timeout,
             },
         )
@@ -125,18 +123,17 @@ class Base:
             )
 
     def __del__(self):
-        """Drop the artifact directory when the rotation is disabled."""
+        """Drop the private_data_dir if it is temporary."""
         if (
-            self._rotate_artifacts is not None
-            and self._runner_artifact_dir
-            and os.path.exists(self._runner_artifact_dir)
+            self._private_data_dir_is_tmp
+            and self._private_data_dir
+            and os.path.exists(self._private_data_dir)
         ):
-
             self._logger.debug(
-                "delete ansible-runner artifact directory at path %s",
-                self._runner_artifact_dir,
+                "delete temporary ansible-runner private_data_dir at path %s",
+                self._private_data_dir,
             )
-            shutil.rmtree(self._runner_artifact_dir, ignore_errors=True)
+            shutil.rmtree(self._private_data_dir, ignore_errors=True)
 
     @staticmethod
     def _generate_tmp_directory():
@@ -156,25 +153,17 @@ class Base:
                 private_data_directory = provided
                 source = "user provided"
             else:
-                self._logger.debug("Provided private data dir `%s` was not user writable")
+                self._logger.debug("Provided private data dir `%s` was not user writable", provided)
                 private_data_directory = self._generate_tmp_directory()
                 source = "user provided, but changed to tmp location due to permissions"
         else:
             private_data_directory = self._generate_tmp_directory()
             source = "not user provided, used tmp location"
 
+        self._private_data_dir_is_tmp = source != "user provided"
         self._private_data_dir = private_data_directory
         self._logger.debug("private data dir %s: %s", source, self._private_data_dir)
 
-    def runner_artifacts_handler(self, artifact_dir):
-        """Ansible-runner callback to handle artifacts after each runner invocation.
-
-        :param artifact_dir: The directory path of artifact directory for current
-            runner invocation.
-        """
-        self._logger.debug("ansible-runner artifact_dir set to: '%s'", artifact_dir)
-        self._runner_artifact_dir = artifact_dir
-
     def runner_cancelled_callback(self):
         """Check by runner to see if it should cancel.
 
@@ -191,6 +180,7 @@ class Base:
         self.finished = True
 
     def _add_env_vars_to_args(self):
+        """Add environment variables to runner args."""
         self._runner_args["envvars"] = {
             k: v for k, v in os.environ.items() if k.startswith("ANSIBLE_")
         }
