@@ -43,7 +43,7 @@ class Compiler:
         self._rule_to_grammar[rule] = grammar
         return rule
 
-    @functools.lru_cache(maxsize=None)
+    @functools.cache
     def _include(
         self,
         grammar: Grammar,
@@ -65,7 +65,7 @@ class Compiler:
             grammar = self._grammars.grammar_for_scope(scope)
             return self._include(grammar, grammar.repository, f"#{s}")
 
-    @functools.lru_cache(maxsize=None)
+    @functools.cache
     def _patterns(
         self,
         grammar: Grammar,
