@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import TYPE_CHECKING
 from typing import NamedTuple
 from typing import Tuple
@@ -9,28 +11,28 @@ if TYPE_CHECKING:
 
 
 class State(NamedTuple):
-    entries: Tuple["Entry", ...]
-    while_stack: Tuple[Tuple["WhileRule", int], ...]
+    entries: tuple[Entry, ...]
+    while_stack: tuple[tuple[WhileRule, int], ...]
 
     @classmethod
-    def root(cls, entry: "Entry") -> "State":
+    def root(cls, entry: Entry) -> State:
         return cls((entry,), ())
 
     @property
-    def cur(self) -> "Entry":
+    def cur(self) -> Entry:
         return self.entries[-1]
 
-    def push(self, entry: "Entry") -> "State":
+    def push(self, entry: Entry) -> State:
         return self._replace(entries=(*self.entries, entry))
 
-    def pop(self) -> "State":
+    def pop(self) -> State:
         return self._replace(entries=self.entries[:-1])
 
-    def push_while(self, rule: "WhileRule", entry: "Entry") -> "State":
+    def push_while(self, rule: WhileRule, entry: Entry) -> State:
         entries = (*self.entries, entry)
         while_stack = (*self.while_stack, (rule, len(entries)))
         return self._replace(entries=entries, while_stack=while_stack)
 
-    def pop_while(self) -> "State":
+    def pop_while(self) -> State:
         entries, while_stack = self.entries[:-1], self.while_stack[:-1]
         return self._replace(entries=entries, while_stack=while_stack)
