@@ -1,7 +1,7 @@
 from __future__ import annotations
 
+from re import Match  # noqa: F401
 from typing import List  # noqa: F401
-from typing import Match  # noqa: F401
 from typing import TypeVar
 
 
