@@ -9,9 +9,9 @@ import curses
 import functools
 import json
 import logging
-import os
 import re
 
+from importlib.abc import Traversable
 from itertools import chain
 
 from ..tm_tokenize.grammars import Grammars
@@ -84,7 +84,7 @@ class ColorSchema:
 class Colorize:
     """Functionality for coloring."""
 
-    def __init__(self, grammar_dir: str, theme_path: str):
+    def __init__(self, grammar_dir: Traversable, theme_path: Traversable):
         """Initialize the colorizer.
 
         :param grammar_dir: The directory in which the grammars reside
@@ -92,13 +92,13 @@ class Colorize:
         """
         self._logger = logging.getLogger(__name__)
         self._schema: ColorSchema
-        self._grammars = Grammars(grammar_dir)
+        self._grammars = Grammars(str(grammar_dir))
         self._theme_path = theme_path
         self._load()
 
     def _load(self):
         """Load the color scheme from the file system."""
-        with open(os.path.join(self._theme_path), encoding="utf-8") as fh:
+        with self._theme_path.open(mode="r", encoding="utf-8") as fh:
             self._schema = ColorSchema(json.load(fh))
 
     @staticmethod
