@@ -1,9 +1,8 @@
 """A field with a 'working on it message'."""
+from __future__ import annotations
+
 from dataclasses import dataclass
 from typing import Callable
-from typing import List
-from typing import Optional
-from typing import Union
 
 from .curses_window import Window
 from .form_handler_working import FormHandlerWorking
@@ -17,12 +16,12 @@ class FieldWorking:
     """A text input field."""
 
     name: str
-    messages: List[str]
+    messages: list[str]
     current_error: str = ""
     window_handler = FormHandlerWorking
-    valid: Union[bool, Unknown] = unknown
+    valid: bool | Unknown = unknown
     validator: Callable = FieldValidators.null
-    win: Optional[Window] = None
+    win: Window | None = None
 
     @property
     def full_prompt(self) -> str:
