@@ -7,17 +7,17 @@ import logging
 import re
 
 from collections.abc import Mapping
+from collections.abc import Sequence
 from curses import ascii as curses_ascii
 from functools import lru_cache
 from math import ceil
 from math import floor
+from re import Match
+from re import Pattern
 from typing import Any
 from typing import Callable
-from typing import Match
 from typing import NamedTuple
-from typing import Pattern
 from typing import Protocol
-from typing import Sequence
 
 from ..content_defs import ContentFormat
 from ..content_defs import ContentType
@@ -429,7 +429,7 @@ class UserInterface(CursesWindow):
         """
         heading = heading or CursesLines(tuple())
         heading_len = len(heading)
-        footer = self._footer(dict(**STANDARD_KEYS, **key_dict, **END_KEYS))
+        footer = self._footer({**STANDARD_KEYS, **key_dict, **END_KEYS})
         footer_at = self._screen_height - 1  # screen is 0 based index
         footer_len = 1
 
@@ -664,6 +664,11 @@ class UserInterface(CursesWindow):
         return heading, lines
 
     def _show_form(self, obj: Form) -> Form:
+        """Show a form on the display.
+
+        :param obj: The form to show
+        :returns: The form
+        """
         res = obj.present(screen=self._screen, ui_config=self._ui_config)
         return res
 
@@ -830,7 +835,6 @@ class UserInterface(CursesWindow):
         :returns: Interaction with the user
         """
         while True:
-
             if self.scroll() == 0:
                 last_line_idx = min(len(current) - 1, self._screen_height - 3)
             else:
