@@ -15,12 +15,7 @@ if TYPE_CHECKING:
         from typing_extensions import TypeAlias
 
 
-if sys.version_info < (3, 9):
-    from backports import zoneinfo
+if sys.version_info < (3, 10):
+    import importlib_metadata
 else:
-    import zoneinfo
-
-if sys.version_info < (3, 9):
-    import importlib_resources
-else:
-    import importlib.resources as importlib_resources
+    import importlib.metadata as importlib_metadata
